@@ -8,7 +8,7 @@ Perl::Dist::WiX::Fragment::StartMenu - A <Fragment> tag that handles the Start m
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::Fragment::StartMenu version 1.200_100.
+This document describes Perl::Dist::WiX::Fragment::StartMenu version 1.200_101.
 
 =head1 SYNOPSIS
 
@@ -46,7 +46,7 @@ use WiX3::XML::RemoveFolder qw();
 use WiX3::XML::DirectoryRef qw();
 use WiX3::XML::Shortcut qw();
 
-our $VERSION = '1.200_100';
+our $VERSION = '1.200_101';
 $VERSION =~ s/_//ms;
 
 extends 'WiX3::XML::Fragment';
@@ -110,7 +110,7 @@ sub _build_root {
 
 	# Get the directory object so we can create a reference to it.
 	my $tree      = Perl::Dist::WiX::DirectoryTree2->instance();
-	my $directory = $tree->get_directory_object( 'D_' . $directory_id );
+	my $directory = $tree->get_directory_object($directory_id);
 	if ( not defined $directory ) {
 		PDWiX->throw(
 			"Could not find directory object for id $directory_id");
@@ -181,9 +181,9 @@ sub BUILDARGS {
 		description  => 'CPAN Shell (used to install modules)',
 		target       => "[D_PerlBin]cpan.bat",
 		id           => 'CpanShell',
-		working_dir  => PerlBin,
+		working_dir  => 'D_PerlBin',
 		icon_id      => 'I_CpanBat',
-		directory_id => 'App_Menu_Tools',
+		directory_id => 'D_App_Menu_Tools',
 	);
 
 This method creates the tag objects that represent a Start Menu shortcut, 
@@ -198,7 +198,7 @@ the ID for the directory that the shortcut is going to go into.
 
 The C<name>, C<target>, C<working_dir>, and C<id> parameters are required.
 (C<description> defaults to being empty, C<directory_id> defaults to 
-'App_Menu', and a missing C<icon_id> allows Windows to follow its default 
+'D_App_Menu', and a missing C<icon_id> allows Windows to follow its default 
 rules for choosing an icon to display.)
 
 =cut
@@ -242,7 +242,7 @@ sub add_shortcut {
 		);
 	}
 
-	$args{directory_id} ||= 'App_Menu';
+	$args{directory_id} ||= 'D_App_Menu';
 
 	if ( not $self->_root_exists( $args{directory_id} ) ) {
 		$self->_build_root( $args{directory_id} );
@@ -258,17 +258,16 @@ sub add_shortcut {
 	}
 	my $component = WiX3::XML::Component->new( id => "S_$args{id}" );
 	my $shortcut = WiX3::XML::Shortcut->new(
-		id               => "$args{id}",
+		id               => $args{id},
 		name             => $args{name},
 		description      => $args{description},
 		target           => $args{target},
 		icon             => $icon_id,
-		workingdirectory => "D_$args{working_dir}",
+		workingdirectory => $args{working_dir},
 	);
 	$component->add_child_tag($shortcut);
 	my $cf =
-	  WiX3::XML::CreateFolder->new(
-		directory => 'D_' . $args{directory_id} );
+	  WiX3::XML::CreateFolder->new( directory => $args{directory_id} );
 	$component->add_child_tag($cf);
 	$self->_get_root( $args{directory_id} )->add_child_tag($component);
 
